<?php
/*
Plugin Name: Plugin Subir Arriba
Description: Añade un botón para subir arriba en el sitio web.
Version: 1.0
Author: Óscar Amate
Author URI: oscaramate.dev
*/

// Función para agregar el botón de subir arriba al pie de página
function subir_arriba_button_markup() {
    // Obtener la URL del icono desde los ajustes del plugin
    $icon_url = esc_url(get_option('subir_arriba_icon'));

    // Output del botón
    echo '<a href="#" id="subir-arriba-btn" style="display: none; position: fixed; bottom: 100px; right: 20px; z-index: 99;border-radius: 50%;
    line-height: 0px; background: rgba(255, 255, 255, 0.5);"><img src="' . $icon_url . '" alt="Subir arriba"></a>';
}
add_action('wp_footer', 'subir_arriba_button_markup');

// Función para agregar opciones al menú de administración para nuestro plugin
function subir_arriba_settings_menu() {
    add_options_page('Ajustes del Plugin Subir Arriba', 'Subir Arriba', 'manage_options', 'subir-arriba-settings', 'subir_arriba_settings_page');
}
add_action('admin_menu', 'subir_arriba_settings_menu');

// Función para mostrar la página de ajustes en el backend
function subir_arriba_settings_page() {
    ?>
    <div class="wrap">
        <h2>Ajustes del Plugin Subir Arriba</h2>
        <form method="post" action="options.php" enctype="multipart/form-data">
            <?php settings_fields('subir_arriba_settings_group'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Icono para el botón de subir arriba</th>
                    <td>
                        <?php
                        $icon_url = esc_attr(get_option('subir_arriba_icon'));
                        ?>
                        <input type="text" name="subir_arriba_icon" value="<?php echo $icon_url; ?>" />
                        <input type="file" name="subir_arriba_icon_file">
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Registrar la opción para el icono en la base de datos de WordPress
function subir_arriba_register_settings() {
    register_setting('subir_arriba_settings_group', 'subir_arriba_icon', 'subir_arriba_sanitize_icon');
}
add_action('admin_init', 'subir_arriba_register_settings');

// Función para sanitizar el valor del icono
function subir_arriba_sanitize_icon($input) {
    // Verificar si se ha subido un nuevo archivo
    if (isset($_FILES['subir_arriba_icon_file']) && $_FILES['subir_arriba_icon_file']['error'] == UPLOAD_ERR_OK) {
        $uploaded_file = $_FILES['subir_arriba_icon_file'];
        $upload_overrides = array('test_form' => false);
        $movefile = wp_handle_upload($uploaded_file, $upload_overrides);
        if ($movefile && !isset($movefile['error'])) {
            $input = $movefile['url'];
        }
    }
    return $input;
}

// Función para agregar los scripts y estilos necesarios
function subir_arriba_scripts() {
    // Estilos CSS
    echo '<style>
        #subir-arriba-btn {
            display: none;
            position: fixed;
            bottom: 20px;
            right: 20px;
            z-index: 99;
            cursor: pointer;
        }
        #subir-arriba-btn img {
            width: 50px; /* ajusta el tamaño según tu preferencia */
            height: auto; /* para mantener la proporción */
        }
    </style>';
    
    // Agregar script JavaScript
    echo '<script>
    jQuery(document).ready(function($) {
        var offset = 100;
        var duration = 500;

        $(window).scroll(function() {
            if ($(this).scrollTop() > offset) {
                $("#subir-arriba-btn").fadeIn(duration);
            } else {
                $("#subir-arriba-btn").fadeOut(duration);
            }
        });

        $("#subir-arriba-btn").click(function(event) {
            event.preventDefault();
            $("html, body").animate({scrollTop: 0}, duration);
            return false;
        });
    });
    </script>';
}
add_action('wp_footer', 'subir_arriba_scripts');
